@@ -1,5 +1,5 @@
 # Copyright (c) 2007-2008 Roy Marples <roy@marples.name>
-# All rights reserved. Released under the 2-clause BSD license.
+# Released under the 2-clause BSD license.
 
 _ip()
 {
@@ -111,38 +111,32 @@ _add_address()
 		return 0
 	fi
 
-	# Convert an ifconfig line to iproute2
-	if [ "$2" = "netmask" ]; then
-		local one="$1" three="$3"
-		shift; shift; shift
-		set -- "${one}/$(_netmask2cidr "${three}")" "$@"
-	fi
-	
-	# tunnel keyword is 'peer' in iproute2, but 'pointopoint' in ifconfig.
-	if [ "$2" = "pointopoint" ]; then
-		local one="$1"
-		shift; shift
-		set -- "${one}" "peer" "$@"
-	fi
-	
+	local address netmask broadcast peer anycast label scope
+	local valid_lft preferred_lft home nodad
+	address="$1" ; shift
+	while [ -n "$*" ]; do
+		case "$1" in
+			netmask)
+				netmask="/$(_netmask2cidr "$2")" ; shift ; shift ;;
+			broadcast|brd)
+				broadcast="broadcast $2" ; shift ; shift ;;
+			pointopoint|pointtopoint|peer)
+				peer="peer $2" ; shift ; shift ;;
+			anycast|label|scope|valid_lft|preferred_lft)
+				eval "$1=$2" ; shift ; shift ;;
+			home|nodad)
+				eval "$1=$1" ; shift ;;
+		esac
+	done
+
 	# Always scope lo addresses as host unless specified otherwise
 	if [ "${IFACE}" = "lo" ]; then
-		set -- "$@" "scope" "host"
+		[ -z "$scope" ] && scope="scope host"
 	fi
 
-	# IPv4 specifics
-	case "$1" in
-		*.*.*.*)
-			case "$@" in
-				*" brd "*);;
-				*" broadcast "*);;
-				*) set -- "$@" brd +;;
-			esac
-			;;
-	esac
-
-	veinfo ip addr add "$@" dev "${IFACE}"
-	ip addr add "$@" dev "${IFACE}"
+	set -- "${address}${netmask}" $peer $broadcast $anycast $label $scope dev "${IFACE}" $valid_lft $preferred_lft $home $nodad
+	veinfo ip addr add "$@"
+	ip addr add "$@"
 }
 
 _add_route()
@@ -162,7 +156,7 @@ _add_route()
 		set -- "${one}" "${two}" via "$@"
 	fi
 
-	local cmd= have_metric=false 
+	local cmd= have_metric=false
 	while [ -n "$1" ]; do
 		case "$1" in
 			metric) cmd="${cmd} $1"; have_metric=true;;
@@ -221,7 +215,7 @@ _ip_rule_runner() {
 	local IFS="$__IFS"
 	for ru in $rules ; do
 		unset IFS
-		ruN="$(trim "${ru}")"
+		ruN="$(_trim "${ru}")"
 		[ -z "${ruN}" ] && continue
 		vebegin "${cmd} ${ruN}"
 		ip rule ${cmd} ${ru}
@@ -239,9 +233,14 @@ iproute2_pre_start()
 	if [ -n "${tunnel}" ]; then
 		# Set our base metric to 1000
 		metric=1000
+		# Bug#347657: If the mode is 'ipip6' or 'ip6ip6', the -6 must be passed
+		# to iproute2 during tunnel creation.
+		local ipproto=''
+		[ "${tunnel##mode ipip6}" != "${tunnel}" ] && ipproto='-6'
+		[ "${tunnel##mode ip6ip6}" != "${tunnel}" ] && ipproto='-6'
 
 		ebegin "Creating tunnel ${IFVAR}"
-		ip tunnel add ${tunnel} name "${IFACE}"
+		ip ${ipproto} tunnel add ${tunnel} name "${IFACE}"
 		eend $? || return 1
 		_up
 	fi
