@@ -9,8 +9,7 @@
 
 /*
  * Copyright (c) 2007-2009 Roy Marples <roy@marples.name>
- * All rights reserved
-
+ *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
  * are met:
@@ -600,7 +599,7 @@ expand_home(const char *home, const char *path)
 }
 
 #include "_usage.h"
-#define getoptstring "I:KN:PR:Sbc:d:e:g:ik:mn:op:s:tu:r:w:x:1:2:" getoptstring_COMMON
+#define getoptstring "I:KN:PR:Sa:bc:d:e:g:ik:mn:op:s:tu:r:w:x:1:2:" getoptstring_COMMON
 static const struct option longopts[] = {
 	{ "ionice",       1, NULL, 'I'},
 	{ "stop",         0, NULL, 'K'},
@@ -788,12 +787,11 @@ start_stop_daemon(int argc, char **argv)
 			background = true;
 			break;
 
-		case 'u':  /* --user <username>|<uid> */
 		case 'c':  /* --chuid <username>|<uid> */
-		{
 			/* DEPRECATED */
 			ewarn("WARNING: -c/--chuid is deprecated and will be removed in the future, please use -u/--user instead");
-
+		case 'u':  /* --user <username>|<uid> */
+		{
 			p = optarg;
 			tmp = strsep(&p, ":");
 			changeuser = xstrdup(tmp);
@@ -1185,8 +1183,6 @@ start_stop_daemon(int argc, char **argv)
 			pamr = pam_start("start-stop-daemon",
 			    "nobody", &conv, &pamh);
 
-		if (pamr == PAM_SUCCESS)
-			pamr = pam_authenticate(pamh, PAM_SILENT);
 		if (pamr == PAM_SUCCESS)
 			pamr = pam_acct_mgmt(pamh, PAM_SILENT);
 		if (pamr == PAM_SUCCESS)
